# lasertram
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT) [![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff) !['coverage'](/images/COVERAGE.svg)


Welcome to the repository for `lasertram`, a package for the time resolved analysis for processing laser ablation inductively coupled plasma mass spectrometry (LA-ICP-MS) data. It is utilized heavily in the dashboard [LaserTRAM-DB](https://github.com/jlubbersgeo/laserTRAM-DB).

## Documentation

please see the [Documentation](https://jlubbersgeo.github.io/lasertram/) for more!

## Installation
[![PyPI](https://img.shields.io/pypi/v/lasertram.svg?style=flat)](https://pypi.python.org/pypi/lasertram)
[![Compatible Python Versions](https://img.shields.io/pypi/pyversions/lasertram.svg?style=flat)](https://pypi.org/project/lasertram/)
```
pip install lasertram
```

## Contributing
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black) [![Code Quality](https://api.codacy.com/project/badge/Grade/fd9912a3faae43bf84a47e3da685d84c)](https://app.codacy.com/gh/jlubbersgeo/lasertram/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=jlubbersgeo/lasertram&amp;utm_campaign=Badge_Grade)

If you have features you'd like to see please open an issue or consider contributing yourself! I'm always happy to have help.

**Maintainer** Jordan Lubbers (jlubbers _at_ usgs.gov)
